/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */
define(["qpid/common/util", "dijit/form/CheckBox", "dojo/domReady!"], function (util)
{

    var fieldNames;

    function ManagedGroupProvider(data)
    {
        fieldNames = util.getTypeFields(data.parent.management.metadata, "GroupProvider", "ManagedGroupProvider");
        util.buildUI(data.containerNode, data.parent, "groupprovider/managedgroupprovider/show.html", fieldNames, this);
    }

    ManagedGroupProvider.prototype.update = function (data)
    {
        util.updateUI(data, fieldNames, this, {"caseSensitive": util.buildCheckboxMarkup});
    };

    return ManagedGroupProvider;
});
